.BG
.FN ash2
.TL
Averaged Shifted Histogram Nonparametric Density Function (2-D)
.DN
Computes a 2-D ASH with product polynomial kernel weights.
.CS
ash2(bins, m=c(5,5), kopt=c(2,2), warn=T)
.RA
.AG bins
list from function "bin2" containing:
.br
$nc=integer matrix of bin counts and
.br
$ab=bin intervals.
.OA
.AG m
integer smoothing parameters;  default=c(5,5).  The usual
smoothing parameter h = m times the bin width.
.AG kopt
vector of length 2 specifying the kernel, which
is proportional to ( 1 - abs(i/m)**kopt[1] )**kopt[2]:
.br
c(0,0) = uniform kernel
.br
c(1,0) = triangle kernel
.br
c(2,1) = Epanechnikov kernel
.br
c(2,2) = biweight (the default)
.br
c(2,3) = triweight kernel
.AG warn
suppress warning messages if False.
.RT
a list suitable for input to "persp" or "contour" containing:
.RC z
matrix of ASH density estimates.  z[i,j] is the
value at x=x[i] and y=y[j].
.RC x
vector of bin center locations along x-axis.
.RC y
vector of bin center locations along y-axis.
.RC ier
0=normal exit; 1=estimate nonzero outside interval ab
.RC m,ab,kopt
includes these input values for record keeping
.SH REFERENCES
Scott, D.W. (1985).  "Averaged Shifted Histograms:
Effective Nonparametric Density Estimators in Several Dimensions."
Annals of Statistics, 80, 348-354.
.PP
Scott, D.W. (1992).  Multivariate Density Estimation:
Theory, Practice, and Visualization.  John Wiley & Sons, New York.
.SA
bin2, bin1, ash1, compress, ashn, density, ksmooth
.EX
Continuing example from help.name("bin2")

m <- c(5,5)
f <- ash2(bins,m)
persp( f$z / max(f$z) )
contour( f )

# Note:  it is a good idea not to plot contours at level = 0.
.KW ash, kernel, density, histogram, binning
.WR
