.BG
.FN ashn
.TL
Averaged Shifted Histogram Nonparametric Density (3-D or More)
.DN
Compute and display three dimensional contours (or slices)
of a multivariate ASH with between 3 and 10 variables.
.CS
ashn(ix, ioauto=0, master=mymaster, ctable=ct, ff=4, mv=rep(1,ncol(ix$nc)), square=c(0,450), sun50=0, mmax=10, ireg=0, iclass=rep(1,nrow(ix$nc)))
.RA
.AG ix
list from function "compress" containing:
.br
$nc = integer matrix of data in bin location form.
.br
$ab = bin intervals.
.br
$nbin = number of bin intervals.
.OA
.AG ioauto
ioauto=0 for interactive mode (the default); ioauto=1 for
batch mode (all input is taken from file "stream.s")
.AG master
matrix provided for matching cubes algorithm.
.AG ctable
RBG color table (nc x 3).  The matrix provided is 101 x 3.
The first color is the background color.  The next 50
colors are for "outside" of shells;  the remaining 50 colors
are for "inside" of shells.  If using the motif driver,
create a new color scheme with "gray" in Background, and
"blue 48 lightblue red 48 white" in Polygons.
.AG ff
Fraction for level of contour on input;  see option 3 below.
.AG mv
Smoothing parameters m on input;  see option 2 below.
.AG square
Deprecated.  Do not change.
.AG sun50
Deprecated.
.AG mmax
Maximum value of any smoothing parameter that will
be used.  Default is 10.
.AG ireg
Default value is ireg=0.
If ireg=1, provides for the
option of inputting a precomputed ash or regression
estimate for visualization only.  The input "ix"
variable must be augmented by a real array "ix$regress"
which contains the estimates, and should be the same
dimension as ix$nc.
.AG iclass
Integer vector indicating the class membership of
each input data point.  Useful for superimposing
shells from different subsets of the data (but on
the same scale).
.RT
The estimated ash array is returned (invisibly).
.SE
The graphical parameters are altered but not reset on exit.
The margins are affected.
.DT
There are 20 control options available in the program.
These are described below.  This may be automated using
the batch option ioauto as described above.  The available
ACTION OPTIONS are:
.PP
0 ==> plot the current contour shell at level "f".
The ash is recomputed only if necessary.
.PP
1 ==> select t slice desired.  Variables beyond the first three
are referred to as "t" variables.  The ash slice
f(x,y,z,t1,t2,..) is selected, where t1,t2,... indicate
the bin number of the t variables.  Usually option 15
should be specified as well.
.PP
2 ==> select smoothing parameters m for each variable.
The usual smoothing parameter h = m times the bin width.
See mmax above.  Default is (1,1,1,...).
.PP
3 ==> select fraction f of contour level where 0 < f < 1.
The contour level displayed is f times the value at the mode
(or "fmaxin" if specified; see option 15).
Thus f=.9 returns a high density around the mode(s),
while f=0.1 returns a low density contour in the tails.
See option 19.
.PP
4 ==> 1/0 if want/don't want to see the axes drawn.
Default is 1.
.PP
5 ==> 1/0 if want/don't want to see the bounding cube drawn.
Default is 1.
.PP
6 ==> vector of length 3 giving the viewpoint of the
observer, assuming the figure is center at the origin.
Default is (1,1,0).  Try (2,5,1).
.PP
7 ==> You can control the bins displayed for the contour.
Default is 1 to nbin[i]-1.  One bin is "lost" in each
dimension since the marching cubes algorithm traverses
the hypercube of bin centers of the ash.
.PP
8 ==> You can control the increments in the bins displayed.
Default is (1,1,1) but try (2,1,1), especially if there are
many triangles found.
.PP
9 ==> Deprecated.  Special code for old SGI Iris graphics.
.PP
10 ==> 1/0 is want/don't want to display only triangles
facing your viewpoint.  Default 0 (everything displayed).
.PP
11 ==> You can create "quad" files that can be visualized
with the "geomview" program.  Multiple quad files can be
produced, and are numbered sequentially.
.br
\ \ \ 0 == no quad file produced
.br
\ \ \ 1 == a CNQUAD file (corner/normal/RGB/transparency)
.br
\ \ \ 2 == a CQUAD filet (corner/RGB/transparency)
.br
\ \ \ 3 == both CNQUAD and CQUAD files are produced
.PP
12 ==> Deprecated (color table lookup)
.PP
13 ==> 1/0 if want/don't want the screen erased before
draw next contour.  Affects option 11 as well.
Useful for displaying multiple contours and/or contours
from different classes (subsets) of the data.
.PP
14 ==> Specifies color for QUAD files in option 11.
A vector of length 4 containing the RGB color
values and a transparency value for the triangles in
the current contour.  Floating point numbers in (0,1).
A value of 1 implies an opaque triangle.
.PP
15 ==> Optional input "fmaxin" to use instead
of the computed "fmax".  Ordinarily, the maximum ash value is
computed for each set of parameters;  however, if
there are more than 3 variables, then you will want
to use the same value of fmax for all slices.
Also useful if ireg=1.
.PP
16 ==> Default kernel is triangle.  Enter "iexp"
and the kernel becomes (1-x^2)**iexp.  Note
that proper normalization is not currently taken.
.PP
17 ==> Select subset of data.  Enter nonnegative
integer contained in vector "iclass".  A value
of -1 selects all points.
.PP
18 ==> Returns percentage of sample contained
within the current "f" contour level.
.PP
19 ==> Set the value of "f" to contain a desired
fraction of the data within the contour level.
Note that the ash must be recomputed if necessary
before using this option.
.PP
99 ==> Quit (returning current ash array estimate).
.SH REFERENCES
Scott, D.W. (1985).  "Averaged Shifted Histograms:
Effective Nonparametric Density Estimators in Several Dimensions."
Annals of Statistics, 80, 348-354.
.PP
Scott, D.W. (1992).  Multivariate Density Estimation:
Theory, Practice, and Visualization.  John Wiley & Sons, New York.
.SA
compress, bin1, ash1, bin2, ash2, density, ksmooth
.EX
Continuing the example in help.name("compress")

ashn(xyz)
    2  3 3 3     # set smoothing parameters
    3  .2        # choose contour level (20% of mode level)
    6  2 5 1     # set viewpoint
    0            # estimate and plot ash contour
   11  0         # don't erase the current contour
    3  .6        # 60% of mode level
    0            # draws over contour (use option 11 if possible)
   99            # exit ashn

ashn(ix,ioauto=1,iclass=whatever)  # uses file "stream.s" for input
                                   # iclass contains group labels
.KW ash, kernel, density, histogram, binning
.WR
