ashn <- function( ix, ioauto=0, master=mymaster, ctable=ct, ff=4,
	mv=rep(1,ncol(ix$nc)), square=c(0,450), sun50=0, mmax=10, ireg=0,
	iclass=rep(1,nrow(ix$nc)) ) {

##### S function to compute and plot n-d ASH slice over cube [-1,1]^3
##### Copyright 1988,1992,1994 David W. Scott

#  ix ----------- data structure containing:
#	nc	- integer data matrix  (n x nvar) - ignores skipped data
#	ab	- bin range matrix (nvar x 2)
#			[ ab[1,1] , ab[1,2] ] contains x-axis range
#			[ ab[2,1] , ab[2,2] ] contains y-axis range
#			[ ab[3,1] , ab[3,2] ] contains z-axis range
#	nbin	- vector length nvar;  number of bins along each axis
#	mmax	- maximum allowed value of m;  dimensioned (m+1)^3
#	iexp	- alternate kernel (0==triangle 1=Epan 2=biweight 3=triweight)
#	regress	- optional array of regression estimates (in "ix")
#	iclass	- integer group designator for each point

nvar <- ncol(ix$nc);  if(nvar<3) stop("less than 3 data variables")
if( !is.matrix(ix$nc) | !is.integer(ix$nc) ) stop("ix$nc should be integer matrix")
if( any(dim(ix$ab) != c(nvar,2)) ) stop("dim of ix$ab should be nvarx2")
if( !is.integer(ix$nbin) | length(ix$nbin)!=nvar ) stop("ix$nbin should be integer vector nvar")
if( !is.matrix(ctable) | !is.single(ctable) ) stop("ctable not an single matrix")
if( nrow(ix$nc)!=length(iclass) ) stop("iclass wrong length --- check if compress skipped points")

#	tri	- 220 x 4 matrix
#			a.  sides connected for triangle
#			b.  corner that indicates decreasing/increasing
#	cuts	- list of 500 triangles for the 254 cases
#	contour	- 254 x 2 (256 cases: 0 and 255 imply no triangles)
#			a.  pointer to first triangle
#			b.  number of triangles in this case
#	orth?	- default 0==> all triangles   1==> only "outside" triangles

if( any(dim(master$tri) != c(220,4)) ) stop("master$tri not 220 x 4")
if( length(master$cuts) != 500 ) stop("master$cuts not 500 long")
if( any(dim(master$contour) != c(254,2)) ) stop("master$contour not 254 x 2")

#	data have been compressed into integer matrix
#	mmax is maximum m allowed for kernel array (default 6)

	mp1 <- rep( mmax+1, 3)		# dimensioned (0:mmax)
			# WEIGHT ARRAY REALLY has 3 in dimension here

# ctable:  1 row == background color	###of rows should be odd
#	rows 2-(nr+1)/2 are the OUTER colors  --  edge to middle
#	last rows are INNER colors  --  edge to middle
#  S refers to these colors as 0 to nr-1

color <- integer(4)
color[1] <- 1; color[4] <- nrow(ctable)-1
color[2] <- max(color[4]/2,color[1]); color[3] <- min(color[2]+1,color[4])
		# color[1:2] towards eye   color[3:4] away from eye

wk <- single( prod(mp1) ) # STRUCTURE( wk/REAL,ARRAY,3,mp1/ )	# ASH weight array
xfmax <- single( ix$nbin[1] )
yfmax <- single( ix$nbin[2] )
zfmax <- single( ix$nbin[3] )
tx <- single( ix$nbin[1] )
ty <- single( ix$nbin[2] )
tz <- single( ix$nbin[3] )
if ( ireg != 1 ) {ash <- single( prod(ix$nbin[1:3]) ) }	# ARRAY
   else { if( !is.array(ix$regress) | is.integer(ix$regress) )  { 
		stop("regress not a real array") }
	  if( any( dim(ix$regress) != ix$nbin) )
		stop("ix$nbin and ix$regress do not agree")
	  ash <- ix$regress }
n <- nrow(ix$nc)

z <- .Fortran("ashn", as.integer(ix$nc), as.integer(n),as.integer(nvar),
	as.single(ix$ab), as.integer(ix$nbin), ash=as.single(ash),
	as.single(xfmax), as.single(yfmax), as.single(zfmax),
	as.single(tx), as.single(ty), as.single(tz),
	as.single(wk), as.integer(mmax),
	as.integer(master$contour), as.integer(master$cuts),
	as.integer(master$tri), as.integer(color),
	as.integer(square), as.integer(sun50),
	as.single(ctable), as.integer(nrow(ctable)),
	as.integer(mv), as.single(ff), as.integer(ioauto), as.integer(ireg),
	as.integer(iclass) )

invisible( array(z$ash,ix$nbin[1:3]) )
}
