compress <- function ( x, ab=t(apply(x,2,nicerange)), nbin=rep(30,ncol(x)) ) {
   n <- nrow(x); nvar <- ncol(x); if( ncol(ab) != 2 ) stop("ab should have 2 columns")
   if( nrow(ab)!=nvar||length(nbin)!=nvar) stop("dimensions of x,ab,nbin do not agree")
   if( min(nbin) <= 0 ) stop("nbin must be positive")

##### S function to compress data into binned integer form
##### Copyright 1988,1992 David W. Scott

#	x	- input trivariate data matrix  (n x nvar)
#	ab	- input bin range matrix (nvar x 2)
#			x binned over [ ab[1,1], ab[1,2] )
#			y binned over [ ab[2,1], ab[2,2] )
#			z binned over [ ab[3,1], ab[3,2] ) etc.
#	nbin	- vector length nvar - number of bins along each axis
#	nout	- subset of n data points in bin range
#	nc	- output matrix (nout x nvar) containing trivariate bin numbers

del <- (ab[,2]-ab[,1])/nbin	# bin widths
iskip <- 0	# number of points not in trivariate bins
nout <- 0	# number of points in output array

		# loop on data
nc <- matrix(0,n,nvar); k <- NULL
for( i in 1:nvar ) {	if( ab[i,1] >= ab[i,2]) stop("ab array incorrectly ordered")
			nc[,i] <- floor( (x[,i]-ab[i,1])/del[i] + 1.0 )
			k <- unique( c( k, seq(n)[ nc[,i]<1 | nc[,i]>nbin[i] ] ) ) }

iskip <- length(k); if(iskip>0) {nc <- nc[-k,];
	print(paste(as.character(iskip),"point(s) not in hyper-rectangle")) }

storage.mode(nc)   <- "integer"
storage.mode(ab)   <- "single"
storage.mode(nbin) <- "integer"
return(nc=nc,ab=ab,nbin=nbin) }

nicerange <- function(x,beta=.1) { ab <- range(x)	# interval surrounding data
	del <- (ab[2]-ab[1])*beta/2; return( c( ab+c(-del,del) ) ) }

